package Nix::Config;

use MIME::Base64;

$version = "1.11.7";

$binDir = $ENV{"NIX_BIN_DIR"} || "/nix/store/4ssykr786d0wp7y6m4xd4qwqs4nrry1z-nix-1.11.7/bin";
$libexecDir = $ENV{"NIX_LIBEXEC_DIR"} || "/nix/store/4ssykr786d0wp7y6m4xd4qwqs4nrry1z-nix-1.11.7/libexec";
$stateDir = $ENV{"NIX_STATE_DIR"} || "/nix/var/nix";
$manifestDir = $ENV{"NIX_MANIFESTS_DIR"} || "/nix/var/nix/manifests";
$logDir = $ENV{"NIX_LOG_DIR"} || "/nix/var/log/nix";
$confDir = $ENV{"NIX_CONF_DIR"} || "/etc/nix";
$storeDir = $ENV{"NIX_STORE_DIR"} || "/nix/store";

$caBundle = $ENV{"NIX_SSL_CERT_FILE"} // $ENV{"SSL_CERT_FILE"} // $ENV{"CURL_CA_BUNDLE"} // $ENV{"OPENSSL_X509_CERT_FILE"};
$caBundle = "/etc/ssl/certs/ca-bundle.crt" if !$caBundle && -f "/etc/ssl/certs/ca-bundle.crt";
$caBundle = "/etc/ssl/certs/ca-certificates.crt" if !$caBundle && -f "/etc/ssl/certs/ca-certificates.crt";

$curlCaFlag = defined $caBundle ? "--cacert $caBundle" : "";

$bzip2 = "/nix/store/hia247wa09mffcyp66412zg8gliqyw91-bzip2-1.0.6.0.1-bin/bin/bzip2";
$xz = "/nix/store/5cpnwwnasypdi7p0av6qbaf52y99gmdz-xz-5.2.2-bin/bin/xz";
$curl = "/nix/store/smll0knq0h37rsj13rl5kc8ql7kxvr5f-curl-7.53.0-bin/bin/curl";
$openssl = "/nix/store/a1n60rwxn1v8y9y9azql969x71xagqzy-openssl-1.0.2k-bin/bin/openssl";

$useBindings = "yes" eq "yes";

%config = ();

%binaryCachePublicKeys = ();

$defaultPublicKeys = "cache.nixos.org-1:6NCHdD59X431o0gWypbMrAURkbJ16ZPMQFGspcDShjY=";

sub readConfig {
    if (defined $ENV{'_NIX_OPTIONS'}) {
        foreach my $s (split '\n', $ENV{'_NIX_OPTIONS'}) {
            my ($n, $v) = split '=', $s, 2;
            $config{$n} = $v;
        }
    } else {
        my $config = "$confDir/nix.conf";
        return unless -f $config;

        open CONFIG, "<$config" or die "cannot open ‘$config’";
        while (<CONFIG>) {
            /^\s*([\w\-\.]+)\s*=\s*(.*)$/ or next;
            $config{$1} = $2;
        }
        close CONFIG;
    }

    foreach my $s (split(/ /, $config{"binary-cache-public-keys"} // $defaultPublicKeys)) {
        my ($keyName, $publicKey) = split ":", $s;
        next unless defined $keyName && defined $publicKey;
        $binaryCachePublicKeys{$keyName} = decode_base64($publicKey);
    }
}

return 1;
